@@ -1,10 +1,14 @@
-from autoarray.structures.grids.coordinates import GridCoordinates
-from autoarray.structures.grids.coordinates import GridCoordinatesUniform
+from autoarray.structures.grids.irregular import GridIrregularGrouped
+from autoarray.structures.grids.irregular import GridIrregularGroupedUniform
 from autoarray.structures.grids.iterate import GridIterate
+from autoarray.structures.vector_fields.vector_field_irregular import (
+    VectorFieldIrregular,
+)
 from . import exc
 from . import plot
 from . import util
 from . import mock
+from . import geometry
 from .dataset import preprocess
 from .dataset.imaging import Imaging
 from .dataset.imaging import MaskedImaging
@@ -41,8 +45,9 @@ from .structures.grids import Grid
 from .structures.grids import GridInterpolate
 from .structures.grids import GridRectangular
 from .structures.grids import GridVoronoi
-from .structures.grids import GridCoordinates
-from .structures.grids import GridCoordinatesUniform
+from .structures.grids import GridIrregular
+from .structures.grids import GridIrregularGrouped
+from .structures.grids import GridIrregularGroupedUniform
 from .structures.lines.lines import Line
 from .structures.lines.lines import LineCollection
 from .structures.region import Region
@@ -55,4 +60,4 @@ from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = '0.15.0'
+__version__ = '0.15.1'
