@@ -1,6 +1,6 @@
 from .grids import Grid, GridSparse, GridTransformed, GridTransformedNumpy
 from .iterate import GridIterate
 from .interpolate import GridInterpolate
-from .coordinates import GridCoordinates, GridCoordinatesUniform
+from .irregular import GridIrregular, GridIrregularGrouped, GridIrregularGroupedUniform
 from .pixelization import GridRectangular, GridVoronoi
 from .decorators import *
