@@ -1,4 +1,5 @@
 import os
+from os import path
 
 import numpy as np
 import pytest
@@ -6,7 +7,9 @@ import shutil
 
 import autoarray as aa
 
-test_data_dir = "{}/files/imaging/".format(os.path.dirname(os.path.realpath(__file__)))
+test_data_dir = path.join(
+    "{}".format(path.dirname(path.realpath(__file__))), "files", "imaging"
+)
 
 
 def test__array_with_new_shape():
