@@ -445,10 +445,8 @@ class TestReplaceNegativeNoise:
 
         noise_map_2d = np.array([[1.0, 2.0], [3.0, 4.0]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=1.0
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=1.0
         )
 
         assert (noise_map_2d == noise_map_2d).all()
@@ -461,12 +459,8 @@ class TestReplaceNegativeNoise:
 
         noise_map_2d = np.array([[1.0, 0.5], [0.25, 0.125]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d,
-                noise_map_2d=noise_map_2d,
-                target_signal_to_noise=10.0,
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=10.0
         )
 
         assert (noise_map_2d == noise_map_2d).all()
@@ -479,40 +473,32 @@ class TestReplaceNegativeNoise:
 
         noise_map_2d = np.array([[1.0, 0.5], [0.25, 0.125]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=4.0
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=4.0
         )
 
         assert (noise_map_2d == np.array([[1.0, 0.5], [0.25, 0.25]])).all()
 
         noise_map_2d = np.array([[1.0, 0.5], [0.25, 0.125]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=2.0
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=2.0
         )
 
         assert (noise_map_2d == np.array([[1.0, 0.5], [0.5, 0.5]])).all()
 
         noise_map_2d = np.array([[1.0, 0.5], [0.25, 0.125]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=1.0
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=1.0
         )
 
         assert (noise_map_2d == np.array([[1.0, 1.0], [1.0, 1.0]])).all()
 
         noise_map_2d = np.array([[1.0, 0.5], [0.25, 0.125]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=0.5
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=0.5
         )
 
         assert (noise_map_2d == np.array([[2.0, 2.0], [2.0, 2.0]])).all()
@@ -523,10 +509,8 @@ class TestReplaceNegativeNoise:
 
         noise_map_2d = np.array([[3.0, 1.0], [4.0, 8.0]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=1.0
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=1.0
         )
 
         assert (noise_map_2d == np.array([[3.0, 2.0], [4.0, 8.0]])).all()
@@ -535,10 +519,8 @@ class TestReplaceNegativeNoise:
 
         noise_map_2d = np.array([[1.0, 2.0], [40.0, 3.0]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=5.0
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=5.0
         )
 
         assert (noise_map_2d == np.array([[2.0, 4.0], [40.0, 6.0]])).all()
@@ -549,10 +531,8 @@ class TestReplaceNegativeNoise:
 
         noise_map_2d = np.array([[1.0, 0.5, 0.25], [0.25, 0.125, 2.0]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=2.0
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=2.0
         )
 
         assert (noise_map_2d == np.array([[1.0, 0.5, 0.5], [0.5, 0.5, 2.0]])).all()
@@ -561,10 +541,8 @@ class TestReplaceNegativeNoise:
 
         noise_map_2d = np.array([[1.0, 0.5], [0.25, 0.125], [0.25, 2.0]])
 
-        noise_map_2d = (
-            util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
-                image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=2.0
-            )
+        noise_map_2d = util.array.replace_noise_map_2d_values_where_image_2d_values_are_negative(
+            image_2d=image_2d, noise_map_2d=noise_map_2d, target_signal_to_noise=2.0
         )
 
         assert (noise_map_2d == np.array([[1.0, 0.5], [0.5, 0.5], [0.5, 2.0]])).all()
