@@ -251,7 +251,7 @@ class TestBinnedArrays2d:
         assert (binned_array_2d == np.array([[2.5, 4.0], [4.5, 3.0]])).all()
 
     def test__bin_using_mean__array_6x3_to_2x1_and_3x6_to_1x2__uses_mean_correctly(
-        self
+        self,
     ):
 
         array_2d = np.array(
@@ -395,7 +395,7 @@ class TestBinnedArrays2d:
         ).all()
 
     def test__bin_using_quadrature__array_6x3_to_2x1_and_3x6_to_1x2__uses_quadrature_correctly(
-        self
+        self,
     ):
 
         array_2d = np.array(
@@ -740,7 +740,7 @@ class TestBinUpMask2d:
 
 class TestMask1DIndexForPaddedMask2dIndex:
     def test__no_padding__mask_is_full_of_false__returns_indexes_in_ascending_order(
-        self
+        self,
     ):
 
         mask = np.full(fill_value=False, shape=(4, 4))
@@ -836,7 +836,7 @@ class TestBinnedMask1dIndexesForMask2dIndex:
         ).all()
 
     def test__masks_are_rectangular_arrays__include_areas_which_bin_up_is_all_true(
-        self
+        self,
     ):
 
         mask = np.array(
@@ -1008,7 +1008,7 @@ class TestArray1DToBininedArray1d:
         ).all()
 
     def test__masks_are_rectangular_arrays__include_areas_which_bin_up_is_all_true(
-        self
+        self,
     ):
 
         mask = np.array(
@@ -1112,7 +1112,7 @@ class TestBinnedMaskArrayToArray:
         ).all()
 
     def test__masks_are_rectangular_arrays__include_areas_which_bin_up_is_all_true(
-        self
+        self,
     ):
 
         mask = np.array(
@@ -1164,7 +1164,10 @@ class TestBinnedMaskArrayToArrayAll:
 
         mask = np.full(fill_value=False, shape=(4, 4))
 
-        masked_array_1d_for_binned_masked_array_1d_all, binned_masked_array_1d_sizes = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
+        (
+            masked_array_1d_for_binned_masked_array_1d_all,
+            binned_masked_array_1d_sizes,
+        ) = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
             mask=mask, bin_up_factor=2
         )
 
@@ -1177,7 +1180,10 @@ class TestBinnedMaskArrayToArrayAll:
 
         mask = np.full(fill_value=False, shape=(9, 9))
 
-        masked_array_1d_for_binned_masked_array_1d_all, binned_masked_array_1d_sizes = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
+        (
+            masked_array_1d_for_binned_masked_array_1d_all,
+            binned_masked_array_1d_sizes,
+        ) = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
             mask=mask, bin_up_factor=3
         )
 
@@ -1203,7 +1209,7 @@ class TestBinnedMaskArrayToArrayAll:
         ).all()
 
     def test__masks_are_rectangular_arrays__include_areas_which_bin_up_is_all_true(
-        self
+        self,
     ):
 
         mask = np.array(
@@ -1213,7 +1219,10 @@ class TestBinnedMaskArrayToArrayAll:
             ]
         )
 
-        masked_array_1d_for_binned_masked_array_1d_all, binned_masked_array_1d_sizes = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
+        (
+            masked_array_1d_for_binned_masked_array_1d_all,
+            binned_masked_array_1d_sizes,
+        ) = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
             mask=mask, bin_up_factor=2
         )
 
@@ -1235,7 +1244,10 @@ class TestBinnedMaskArrayToArrayAll:
             ]
         )
 
-        masked_array_1d_for_binned_masked_array_1d_all, binned_masked_array_1d_sizes = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
+        (
+            masked_array_1d_for_binned_masked_array_1d_all,
+            binned_masked_array_1d_sizes,
+        ) = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
             mask=mask, bin_up_factor=2
         )
 
@@ -1250,7 +1262,10 @@ class TestBinnedMaskArrayToArrayAll:
 
         mask = np.full(fill_value=False, shape=(5, 5))
 
-        masked_array_1d_for_binned_masked_array_1d_all, binned_masked_array_1d_sizes = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
+        (
+            masked_array_1d_for_binned_masked_array_1d_all,
+            binned_masked_array_1d_sizes,
+        ) = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_all_from(
             mask=mask, bin_up_factor=2
         )
 
