@@ -6,7 +6,7 @@ import numpy as np
 
 class TestUnmaskedSparseForSparse:
     def test__mask_full_false__image_mask_and_pixel_centres_fully_overlap__each_sparse_maps_to_unmaked_sparse(
-        self
+        self,
     ):
 
         ma = aa.Mask2D.manual(
@@ -37,7 +37,7 @@ class TestUnmaskedSparseForSparse:
         ).all()
 
     def test__same_as_above__but_remove_some_centre_pixels_and_change_order__order_does_not_change_mapping(
-        self
+        self,
     ):
 
         ma = aa.Mask2D.manual(
@@ -185,7 +185,7 @@ class TestUnmaskedSparseForSparse:
 
 class TestSparseForUnmaskedSparse:
     def test__mask_full_false__image_mask_and_pixel_centres_fully_overlap__each_pix_maps_to_unmaked_pix(
-        self
+        self,
     ):
 
         ma = aa.Mask2D.manual(
@@ -211,7 +211,7 @@ class TestSparseForUnmaskedSparse:
         ).all()
 
     def test__same_as_above__but_remove_some_centre_pixels_and_change_order__order_does_not_change_mapping(
-        self
+        self,
     ):
 
         ma = aa.Mask2D.manual(
@@ -336,7 +336,7 @@ class TestSparseForUnmaskedSparse:
 
 class TestRegularToSparse:
     def test__simple_cases_for_regular_to_unmasked_sparse_and__sparse_for_unmasked_sparse(
-        self
+        self,
     ):
 
         regular_to_unmasked_sparse = np.array([0, 1, 2, 3, 4])
@@ -382,7 +382,7 @@ class TestRegularToSparse:
 
 class TestSparseGridFromUnmaskedSparseGrid:
     def test__simple_unmasked_sparse_grid__full_grid_pix_grid_same_size__straightforward_mappings(
-        self
+        self,
     ):
 
         unmasked_sparse_grid = np.array(
@@ -425,7 +425,7 @@ class TestSparseGridFromUnmaskedSparseGrid:
         ).all()
 
     def test__simple_unmasked_sparse_grid__full_grid_pix_bigger_than_pix__straightforward_mappings(
-        self
+        self,
     ):
 
         unmasked_sparse_grid = np.array(
